/*
 * Copyright 2007, Hugo Santos. All Rights Reserved.
 * Copyright 2007, Axel Dörfler, axeld@pinc-software.de. All Rights Reserved.
 * Distributed under the terms of the MIT License.
 */


#include <sys/bus.h>
#include <sys/rman.h>
#include "if_skreg.h"


HAIKU_FBSD_DRIVER_GLUE(marvell_yukon_sk, skc, pci)

extern driver_t *DRIVER_MODULE_NAME(e1000phy, miibus);
extern driver_t *DRIVER_MODULE_NAME(ukphy, miibus);
extern driver_t *DRIVER_MODULE_NAME(xmphy, miibus);


driver_t *
__haiku_select_miibus_driver(device_t dev)
{
	driver_t *drivers[] = {
		DRIVER_MODULE_NAME(xmphy, miibus),
		DRIVER_MODULE_NAME(e1000phy, miibus),
		DRIVER_MODULE_NAME(ukphy, miibus),
		NULL
	};

	return __haiku_probe_miibus(dev, drivers);
}

int
__haiku_disable_interrupts(device_t dev)
{
	struct sk_softc *sc = device_get_softc(dev);
	u_int32_t status;

	status = CSR_READ_4(sc, SK_ISSR);
	if (status == 0 || status == 0xffffffff || sc->sk_suspended)
		return 0;

	if (sc->sk_if[0] != NULL)
		sc->sk_intrmask &= ~SK_INTRS1;
	if (sc->sk_if[1] != NULL)
		sc->sk_intrmask &= ~SK_INTRS2;

	CSR_WRITE_4(sc, SK_IMR, sc->sk_intrmask);

	return 1;
}


void
__haiku_reenable_interrupts(device_t dev)
{
	struct sk_softc *sc = device_get_softc(dev);

	CSR_READ_4(sc, SK_ISSR);
	if (sc->sk_if[0] != NULL)
		sc->sk_intrmask |= SK_INTRS1;
	if (sc->sk_if[1] != NULL)
		sc->sk_intrmask |= SK_INTRS2;

//	sc->sk_intrmask |= SK_ISR_EXTERNAL_REG;

	CSR_WRITE_4(sc, SK_IMR, sc->sk_intrmask);
}

HAIKU_DRIVER_REQUIREMENTS(0 /*FBSD_TASKQUEUES | FBSD_FAST_TASKQUEUE | FBSD_SWI_TASKQUEUE*/);

